/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.psi.codeStyle;

import com.intellij.openapi.options.Configurable;
import com.intellij.openapi.options.ConfigurationException;
import org.jetbrains.annotations.NotNull;

/**
 * A configurable used for any code style settings. Allows to operate with model settings updated upon UI changes.
 */
public interface CodeStyleConfigurable extends Configurable {
  /**
   * Reset the UI to the given code style settings.
   *
   * @param settings The settings to update the UI from.
   */
  void reset(@NotNull CodeStyleSettings settings);

  /**
   * Apply the current UI changes to the given settings.
   *
   * @param settings The settings to apply the UI changes to.
   * @throws ConfigurationException If the UI contains incorrect values.
   */
  void apply(@NotNull CodeStyleSettings settings) throws ConfigurationException;
}
